@@ -50,7 +50,7 @@ def walk(path_to_root_file):
 
 
 def _walk(obj, name=None):
-    if not obj.keys():
+    if not hasattr(obj, 'keys') or len(obj.keys()) == 0:
         yield name, obj
     else:
         for k in sorted(obj.keys()):
@@ -115,6 +115,7 @@ def download_from_gitlab(url, output):
     tokens = url.split('/')
     job_name = tokens[0]
     file_path = os.path.join(*tokens[1:])
+    logger.debug(f'Attempting to download file "{file_path}" from pipeline job "{job_name}"')
 
     job = gitlab.get_pipeline_job(job_name)
     gitlab.download_artifact(job.id, path=file_path, output_file=output)
